@@ -18,7 +18,7 @@ from django_codemod.commands import BaseCodemodCommand
 from django_codemod.visitors.base import BaseDjCodemodTransformer
 
 
-def index_codemoders(version_getter: Callable) -> Dict[Tuple[int, int], List]:
+def index_codemodders(version_getter: Callable) -> Dict[Tuple[int, int], List]:
     """
     Index codemodders by version.
 
@@ -36,16 +36,22 @@ def iter_codemodders() -> Generator[BaseDjCodemodTransformer, None, None]:
     for object_name in dir(visitors):
         try:
             obj = getattr(visitors, object_name)
-            if not issubclass(obj, BaseDjCodemodTransformer) or inspect.isabstract(obj):
-                continue
-            # Looks like this one is good to go
-            yield obj
+            if issubclass(obj, BaseDjCodemodTransformer) and not inspect.isabstract(
+                obj
+            ):
+                yield obj  # Looks like this one is good to go
         except TypeError:
             continue
 
 
-DEPRECATED_IN = index_codemoders(version_getter=attrgetter("deprecated_in"))
-REMOVED_IN = index_codemoders(version_getter=attrgetter("removed_in"))
+DEPRECATED_IN = index_codemodders(version_getter=attrgetter("deprecated_in"))
+REMOVED_IN = index_codemodders(version_getter=attrgetter("removed_in"))
+BY_NAME = {cls.__name__: cls for cls in iter_codemodders()}
+
+
+class CodemodChoice(click.Choice):
+    def get_metavar(self, param):
+        return "(see `djcodemod list`)"
 
 
 class VersionParamType(click.ParamType):
@@ -73,7 +79,7 @@ class VersionParamType(click.ParamType):
         if parsed_version not in self.valid_versions:
             supported_versions = ", ".join(
                 ".".join(str(version_part) for version_part in version_tuple)
-                for version_tuple in self.valid_versions
+                for version_tuple in sorted(self.valid_versions)
             )
             self.fail(
                 f"{value!r} is not supported. "
@@ -102,41 +108,61 @@ def djcodemod():
 
 
 @djcodemod.command()
-@click.argument("path")
+@click.argument("path", nargs=-1, required=True)
 @click.option(
     "--removed-in",
     "removed_in",
     help="The version of Django where feature are removed.",
     type=VersionParamType(REMOVED_IN),
+    multiple=True,
 )
 @click.option(
     "--deprecated-in",
     "deprecated_in",
     help="The version of Django where deprecations started.",
     type=VersionParamType(DEPRECATED_IN),
+    multiple=True,
 )
-def run(removed_in: Tuple[int, int], deprecated_in: Tuple[int, int], path: str) -> None:
+@click.option(
+    "--codemod",
+    "codemod",
+    help="Choose a specific codemod to run. Can be repeated.",
+    type=CodemodChoice(BY_NAME.keys()),
+    multiple=True,
+)
+def run(
+    removed_in: List[Tuple[int, int]],
+    deprecated_in: List[Tuple[int, int]],
+    codemod: List[str],
+    path: List[str],
+) -> None:
     """
     Automatically fixes deprecations removed Django deprecations.
 
     This command takes the path to target as argument and a version of
     Django to select code modifications to apply.
     """
-    if not any((removed_in, deprecated_in)) or all((removed_in, deprecated_in)):
+    codemodders_set = set()
+    for version in removed_in:
+        codemodders_set |= set(REMOVED_IN[version])
+    for version in deprecated_in:
+        codemodders_set |= set(DEPRECATED_IN[version])
+    for name in codemod:
+        codemodders_set.add(BY_NAME[name])
+    if not codemodders_set:
         raise click.UsageError(
-            "You must specify either '--removed-in' or '--deprecated-in' but not both."
+            "No codemods were selected. "
+            "Specify '--removed-in' and/or '--deprecated-in' and/or '--codemod'."
         )
-    if removed_in:
-        codemodders_list = REMOVED_IN[removed_in]
-    else:
-        codemodders_list = DEPRECATED_IN[deprecated_in]
+    codemodders_list = sorted(codemodders_set, key=lambda m: m.__name__)
+    click.echo(f"Running codemods: {', '.join(m.__name__ for m in codemodders_list)}")
     command_instance = BaseCodemodCommand(codemodders_list, CodemodContext())
     call_command(command_instance, path)
 
 
-def call_command(command_instance: BaseCodemodCommand, path: str):
+def call_command(command_instance: BaseCodemodCommand, path: List[str]):
     """Call libCST with our customized command."""
-    files = gather_files([path])
+    files = gather_files(path)
     try:
         # Super simplified call
         result = parallel_exec_transform_with_prettyprint(
