@@ -1,5 +1,6 @@
 from .admin import InlineHasAddPermissionsTransformer
 from .core import URLResolversTransformer
+from .crypto import GetRandomStringTransformer
 from .decorators import AvailableAttrsTransformer, ContextDecoratorTransformer
 from .encoding import (
     ForceTextTransformer,
@@ -22,6 +23,7 @@ from .paginator import QuerySetPaginatorTransformer
 from .postgres_fields import (
     FloatRangeFormFieldTransformer,
     FloatRangeModelFieldTransformer,
+    JSONModelFieldTransformer,
 )
 from .shortcuts import RenderToResponseTransformer
 from .signals import SignalDisconnectWeakTransformer
@@ -45,6 +47,7 @@ __all__ = (
     "FloatRangeFormFieldTransformer",
     "FloatRangeModelFieldTransformer",
     "ForceTextTransformer",
+    "GetRandomStringTransformer",
     "HttpRequestXReadLinesTransformer",
     "HttpUrlQuotePlusTransformer",
     "HttpUrlQuoteTransformer",
@@ -52,6 +55,7 @@ __all__ = (
     "HttpUrlUnQuoteTransformer",
     "InlineHasAddPermissionsTransformer",
     "IsSafeUrlTransformer",
+    "JSONModelFieldTransformer",
     "LRUCacheTransformer",
     "ModelsPermalinkTransformer",
     "OnDeleteTransformer",
@@ -62,10 +66,10 @@ __all__ = (
     "UGetTextLazyTransformer",
     "UGetTextNoopTransformer",
     "UGetTextTransformer",
+    "UnescapeEntitiesTransformer",
     "UNGetTextLazyTransformer",
     "UNGetTextTransformer",
-    "URLTransformer",
-    "URLResolversTransformer",
-    "UnescapeEntitiesTransformer",
     "UnicodeCompatibleTransformer",
+    "URLResolversTransformer",
+    "URLTransformer",
 )
