@@ -5,13 +5,7 @@ import pytest
 from click.testing import CliRunner
 from libcst.codemod import CodemodContext, ParallelTransformResult
 
-from django_codemod import cli
-from django_codemod.cli import (
-    DEPRECATED_IN,
-    REMOVED_IN,
-    call_command,
-    get_short_description,
-)
+from django_codemod import cli, visitors
 from django_codemod.commands import BaseCodemodCommand
 
 
@@ -38,27 +32,15 @@ def test_missing_argument(cli_runner):
     result = cli_runner.invoke(cli.djcodemod, ["run"])
 
     assert result.exit_code == 2
-    assert "Error: Missing argument 'PATH'" in result.output
+    assert "Error: Missing argument 'PATH" in result.output
 
 
-@pytest.mark.parametrize(
-    "command_line",
-    [
-        # Missing options
-        ["run", "."],
-        # Too many options
-        ["run", "--removed-in", "3.0", "--deprecated-in", "2.0", "."],
-    ],
-)
-def test_invalid_options(cli_runner, command_line):
+def test_no_mods_selected(cli_runner):
     """Should explain missing option."""
-    result = cli_runner.invoke(cli.djcodemod, command_line)
+    result = cli_runner.invoke(cli.djcodemod, ["run", "."])
 
     assert result.exit_code == 2
-    assert (
-        "Error: You must specify either '--removed-in' or "
-        "'--deprecated-in' but not both." in result.output
-    )
+    assert "No codemods were selected" in result.output
 
 
 def test_help(cli_runner):
@@ -104,12 +86,25 @@ def test_invalid_version(cli_runner):
     assert "'not.a.version' is not a valid version" in result.output
 
 
+def test_run_help(cli_runner):
+    result = cli_runner.invoke(
+        cli.djcodemod,
+        ["run", "--help"],
+    )
+
+    assert result.exit_code == 0
+    assert "--codemod" in result.output
+    assert "--deprecated-in" in result.output
+    assert "--removed-in" in result.output
+    assert "djcodemod list" in result.output
+
+
 @pytest.mark.parametrize(
     ("option", "version"),
     [
-        # Removed in option
         ("--removed-in", "3.0"),
         ("--deprecated-in", "2.0"),
+        ("--codemod", "URLResolversTransformer"),
     ],
 )
 @pytest.mark.parametrize("path", [".", "my_app"])
@@ -137,7 +132,7 @@ def test_call_command_success(command_instance, mocker):
         successes=1, failures=0, warnings=0, skips=0
     )
 
-    result = call_command(command_instance, ".")
+    result = cli.call_command(command_instance, ".")
 
     assert result is None
 
@@ -152,7 +147,7 @@ def test_call_command_failure(command_instance, mocker):
     )
 
     with pytest.raises(click.exceptions.Exit):
-        call_command(command_instance, ".")
+        cli.call_command(command_instance, ".")
 
 
 @pytest.mark.usefixtures("gather_files_mocked")
@@ -166,113 +161,27 @@ def test_call_command_interrupted(command_instance, mocker):
     )
 
     with pytest.raises(click.Abort):
-        call_command(command_instance, ".")
+        cli.call_command(command_instance, ".")
 
 
-def _mapping_repr(mapping):
-    """Helper to return class names in the dict values."""
-    return {
-        version: [klass.__name__ for klass in classes_list]
-        for version, classes_list in mapping.items()
-    }
+def _verify_mapping(mapping, version_attr):
+    seen_names = set()
+    for version, classes in mapping.items():
+        seen_names |= {cls.__name__ for cls in classes}
+        for cls in classes:
+            # Verify we gathered the mapping correctly by version
+            assert getattr(cls, version_attr) == version
+
+    # Verify all codemods exported from visitors are mapped
+    assert seen_names == set(visitors.__all__)
 
 
 def test_deprecated_in_mapping():
-    """Transformers found by the ``DEPRECATED_IN`` mapping."""
-    assert _mapping_repr(DEPRECATED_IN) == {
-        (3, 0): [
-            "ForceTextTransformer",
-            "HttpUrlQuotePlusTransformer",
-            "HttpUrlQuoteTransformer",
-            "HttpUrlUnQuotePlusTransformer",
-            "HttpUrlUnQuoteTransformer",
-            "IsSafeUrlTransformer",
-            "SmartTextTransformer",
-            "UGetTextLazyTransformer",
-            "UGetTextNoopTransformer",
-            "UGetTextTransformer",
-            "UNGetTextLazyTransformer",
-            "UNGetTextTransformer",
-            "URLTransformer",
-            "UnescapeEntitiesTransformer",
-        ],
-        (2, 2): [
-            "FixedOffsetTransformer",
-            "FloatRangeFormFieldTransformer",
-            "FloatRangeModelFieldTransformer",
-            "QuerySetPaginatorTransformer",
-        ],
-        (2, 1): [
-            "InlineHasAddPermissionsTransformer",
-        ],
-        (2, 0): [
-            "AbsPathTransformer",
-            "AvailableAttrsTransformer",
-            "ContextDecoratorTransformer",
-            "HttpRequestXReadLinesTransformer",
-            "LRUCacheTransformer",
-            "RenderToResponseTransformer",
-            "UnicodeCompatibleTransformer",
-        ],
-        (1, 11): [
-            "ModelsPermalinkTransformer",
-        ],
-        (1, 10): [
-            "URLResolversTransformer",
-        ],
-        (1, 9): [
-            "AssignmentTagTransformer",
-            "OnDeleteTransformer",
-            "SignalDisconnectWeakTransformer",
-        ],
-    }
+    _verify_mapping(cli.DEPRECATED_IN, "deprecated_in")
 
 
 def test_removed_in_mapping():
-    """Transformers found by the ``REMOVED_IN`` mapping."""
-    assert _mapping_repr(REMOVED_IN) == {
-        (4, 0): [
-            "ForceTextTransformer",
-            "HttpUrlQuotePlusTransformer",
-            "HttpUrlQuoteTransformer",
-            "HttpUrlUnQuotePlusTransformer",
-            "HttpUrlUnQuoteTransformer",
-            "IsSafeUrlTransformer",
-            "SmartTextTransformer",
-            "UGetTextLazyTransformer",
-            "UGetTextNoopTransformer",
-            "UGetTextTransformer",
-            "UNGetTextLazyTransformer",
-            "UNGetTextTransformer",
-            "URLTransformer",
-            "UnescapeEntitiesTransformer",
-        ],
-        (3, 1): [
-            "FixedOffsetTransformer",
-            "FloatRangeFormFieldTransformer",
-            "FloatRangeModelFieldTransformer",
-            "QuerySetPaginatorTransformer",
-        ],
-        (3, 0): [
-            "AbsPathTransformer",
-            "AvailableAttrsTransformer",
-            "ContextDecoratorTransformer",
-            "HttpRequestXReadLinesTransformer",
-            "InlineHasAddPermissionsTransformer",
-            "LRUCacheTransformer",
-            "RenderToResponseTransformer",
-            "UnicodeCompatibleTransformer",
-        ],
-        (2, 1): [
-            "ModelsPermalinkTransformer",
-        ],
-        (2, 0): [
-            "AssignmentTagTransformer",
-            "OnDeleteTransformer",
-            "SignalDisconnectWeakTransformer",
-            "URLResolversTransformer",
-        ],
-    }
+    _verify_mapping(cli.REMOVED_IN, "removed_in")
 
 
 def test_list_command(cli_runner):
@@ -317,4 +226,4 @@ class MultiLine2:
     ],
 )
 def test_get_short_description(klass, expected_result):
-    assert get_short_description(klass) == expected_result
+    assert cli.get_short_description(klass) == expected_result
